@@ -3,8 +3,7 @@ package File::Spec;
 use strict;
 use vars qw(@ISA $VERSION);
 
-$VERSION = '0.87_02';
-$VERSION = eval $VERSION;
+$VERSION = 0.84 ;
 
 my %module = (MacOS   => 'Mac',
 	      MSWin32 => 'Win32',
@@ -165,8 +164,7 @@ Mac OS (Classic).  It does consult the working environment for VMS
 
 =item path
 
-Takes no argument, returns the environment variable PATH (or the local
-platform's equivalent) as a list.
+Takes no argument, returns the environment variable PATH as an array.
 
     @PATH = File::Spec->path();
 
@@ -222,16 +220,12 @@ from the base path to the destination path:
     $rel_path = File::Spec->abs2rel( $path ) ;
     $rel_path = File::Spec->abs2rel( $path, $base ) ;
 
-If $base is not present or '', then L<cwd()|Cwd> is used. If $base is
-relative, then it is converted to absolute form using
-L</rel2abs()>. This means that it is taken to be relative to
-L<cwd()|Cwd>.
+If $base is not present or '', then L<cwd()|Cwd> is used. If $base is relative, 
+then it is converted to absolute form using L</rel2abs()>. This means that it
+is taken to be relative to L<cwd()|Cwd>.
 
-On systems with the concept of volume, if $path and $base appear to be
-on two different volumes, we will not attempt to resolve the two
-paths, and we will instead simply return $path.  Note that previous
-versions of this module ignored the volume of $base, which resulted in
-garbage results part of the time.
+On systems with the concept of a volume, this assumes that both paths 
+are on the $destination volume, and ignores the $base volume. 
 
 On systems that have a grammar that indicates filenames, this ignores the 
 $base filename as well. Otherwise all path components are assumed to be
@@ -257,11 +251,8 @@ If $base is not present or '', then L<cwd()|Cwd> is used. If $base is relative,
 then it is converted to absolute form using L</rel2abs()>. This means that it
 is taken to be relative to L<cwd()|Cwd>.
 
-On systems with the concept of volume, if $path and $base appear to be
-on two different volumes, we will not attempt to resolve the two
-paths, and we will instead simply return $path.  Note that previous
-versions of this module ignored the volume of $base, which resulted in
-garbage results part of the time.
+On systems with the concept of a volume, this assumes that both paths 
+are on the $base volume, and ignores the $path volume. 
 
 On systems that have a grammar that indicates filenames, this ignores the 
 $base filename as well. Otherwise all path components are assumed to be
@@ -287,11 +278,8 @@ L<File::Spec::Unix>, L<File::Spec::Mac>, L<File::Spec::OS2>,
 L<File::Spec::Win32>, L<File::Spec::VMS>, L<File::Spec::Functions>,
 L<ExtUtils::MakeMaker>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Currently maintained by Ken Williams <KWILLIAMS@cpan.org>.
-
-The vast majority of the code was written by
 Kenneth Albanowski <kjahds@kjahds.com>, Andy Dougherty
 <doughera@lafayette.edu>, Andreas KE<ouml>nig
 <A.Koenig@franz.ww.TU-Berlin.DE>, Tim Bunce <Tim.Bunce@ig.co.uk.
@@ -302,5 +290,3 @@ Mac support by Paul Schinder <schinder@pobox.com>, and Thomas Wegner
 Yamaguchi <shigio@tamacom.com>, modified by Barrie Slaymaker
 <barries@slaysys.com>.  splitpath(), splitdir(), catpath() and
 catdir() by Barrie Slaymaker.
-
-=cut
