@@ -8,14 +8,12 @@ $VERSION = '1.4';
 
 @ISA = qw(File::Spec::Unix);
 
+use Cwd;
 my $macfiles;
 if ($^O eq 'MacOS') {
 	$macfiles = eval { require Mac::Files };
 }
 
-sub case_tolerant { 1 }
-
-
 =head1 NAME
 
 File::Spec::Mac - File::Spec for Mac OS (Classic)
@@ -585,14 +583,10 @@ sub catpath {
 	return $file ;
     }
 
-    my ($dir_volume, $dir_dirs) = $self->splitpath($directory, 1);
-
-    $volume = $dir_volume unless length $volume;
     my $path = $volume; # may be ''
     $path .= ':' unless (substr($path, -1) eq ':'); # ensure trailing ':'
 
     if ($directory) {
-	$directory = $dir_dirs if $volume;
 	$directory =~ s/^://; # remove leading ':' if any
 	$path .= $directory;
 	$path .= ':' unless (substr($path, -1) eq ':'); # ensure trailing ':'
@@ -621,13 +615,11 @@ If $base is not present or '', then the current working directory is used.
 If $base is relative, then it is converted to absolute form using C<rel2abs()>.
 This means that it is taken to be relative to the current working directory.
 
-If $path and $base appear to be on two different volumes, we will not
-attempt to resolve the two paths, and we will instead simply return
-$path.  Note that previous versions of this module ignored the volume
-of $base, which resulted in garbage results part of the time.
+Since Mac OS has the concept of volumes, this assumes that both paths
+are on the $destination volume, and ignores the $base volume (!).
 
 If $base doesn't have a trailing colon, the last element of $base is
-assumed to be a filename.  This filename is ignored.  Otherwise all path
+assumed to be a filename. This filename is ignored (!). Otherwise all path
 components are assumed to be directories.
 
 If $path is relative, it is converted to absolute form using C<rel2abs()>.
@@ -662,7 +654,7 @@ sub abs2rel {
 
     # Figure out the effective $base and clean it up.
     if ( !defined( $base ) || $base eq '' ) {
-	$base = $self->_cwd();
+	$base = cwd();
     }
     elsif ( ! $self->file_name_is_absolute( $base ) ) {
         $base = $self->rel2abs( $base ) ;
@@ -672,11 +664,11 @@ sub abs2rel {
 	$base = _resolve_updirs( $base );
     }
 
-    # Split up paths - ignore $base's file
-    my ( $path_vol, $path_dirs, $path_file ) =  $self->splitpath( $path );
-    my ( $base_vol, $base_dirs )             =  $self->splitpath( $base );
+    # Split up paths
+    my ( $path_dirs, $path_file ) =  ($self->splitpath( $path ))[1,2] ;
 
-    return $path unless lc( $path_vol ) eq lc( $base_vol );
+    # ignore $base's volume and file
+    my $base_dirs = ($self->splitpath( $base ))[1] ;
 
     # Now, remove all leading components that are the same
     my @pathchunks = $self->splitdir( $path_dirs );
@@ -715,7 +707,7 @@ using C<rel2abs()>. This means that it is taken to be relative to the
 current working directory.
 
 If $base doesn't have a trailing colon, the last element of $base is
-assumed to be a filename.  This filename is ignored.  Otherwise all path
+assumed to be a filename. This filename is ignored (!). Otherwise all path
 components are assumed to be directories.
 
 If $path is already absolute, it is returned and $base is ignored.
@@ -730,7 +722,7 @@ sub rel2abs {
     if ( ! $self->file_name_is_absolute($path) ) {
         # Figure out the effective $base and clean it up.
         if ( !defined( $base ) || $base eq '' ) {
-	    $base = $self->_cwd();
+	    $base = cwd();
         }
         elsif ( ! $self->file_name_is_absolute($base) ) {
             $base = $self->rel2abs($base) ;
@@ -742,7 +734,7 @@ sub rel2abs {
         my ( $path_dirs, $path_file ) = ($self->splitpath($path))[1,2] ;
 
         # ignore $base's file part
-	my ( $base_vol, $base_dirs ) = $self->splitpath($base) ;
+	my ( $base_vol, $base_dirs, undef ) = $self->splitpath($base) ;
 
 	# Glom them together
 	$path_dirs = ':' if ($path_dirs eq '');
@@ -762,10 +754,10 @@ sub rel2abs {
 See the authors list in I<File::Spec>. Mac OS support by Paul Schinder
 <schinder@pobox.com> and Thomas Wegner <wegner_thomas@yahoo.com>.
 
+
 =head1 SEE ALSO
 
-See L<File::Spec> and L<File::Spec::Unix>.  This package overrides the
-implementation of these methods, not the semantics.
+L<File::Spec>
 
 =cut
 
